@@ -93,7 +93,7 @@ if (isset($_REQUEST['total_rows']) && $_REQUEST['total_rows']) {
     $total_rows = PMA_getCentralColumnsCount($db);
 }
 if (PMA_isValid($_REQUEST['pos'], 'integer')) {
-    $pos = $_REQUEST['pos'];
+    $pos = intval($_REQUEST['pos']);
 } else {
     $pos = 0;
 }
