@@ -86,13 +86,13 @@ AJAX.registerTeardown('tbl_structure.js', function () {
     $(document).off('submit', ".append_fields_form.ajax");
     $('body').off('click', '#fieldsForm.ajax button[name="submit_mult"], #fieldsForm.ajax input[name="submit_mult"]');
     $(document).off('click', 'a[name^=partition_action].ajax');
+    $(document).off('click', '#remove_partitioning.ajax');
 });
 
 AJAX.registerOnload('tbl_structure.js', function () {
 
     // Re-initialize variables.
     primary_indexes = [];
-    unique_indexes = [];
     indexes = [];
     fulltext_indexes = [];
     spatial_indexes = [];
@@ -213,7 +213,7 @@ AJAX.registerOnload('tbl_structure.js', function () {
         var question = PMA_sprintf(PMA_messages.strDoYouReally, 'ALTER TABLE `' + escapeHtml(curr_table_name) + '` DROP `' + escapeHtml(curr_column_name) + '`;');
         $(this).PMA_confirm(question, $(this).attr('href'), function (url) {
             var $msg = PMA_ajaxShowMessage(PMA_messages.strDroppingColumn, false);
-            $.get(url, {'is_js_confirmed' : 1, 'ajax_request' : true, 'ajax_page_request' : true}, function (data) {
+            $.post(url, {'is_js_confirmed' : 1, 'ajax_request' : true, 'ajax_page_request' : true}, function (data) {
                 if (typeof data !== 'undefined' && data.success === true) {
                     PMA_ajaxRemoveMessage($msg);
                     if ($('.result_query').length) {
@@ -245,18 +245,18 @@ AJAX.registerOnload('tbl_structure.js', function () {
                 } else {
                     PMA_ajaxShowMessage(PMA_messages.strErrorProcessingRequest + " : " + data.error, false);
                 }
-            }); // end $.get()
+            }); // end $.post()
         }); // end $.PMA_confirm()
     }); //end of Drop Column Anchor action
 
     /**
-     * Attach Event Handler for 'Print View'
+     * Attach Event Handler for 'Print' link
      */
     $(document).on('click', "#printView", function (event) {
         event.preventDefault();
 
-        // Print the page
-        printPage();
+        // Take to preview mode
+        printPreview();
     }); //end of Print View action
 
     /**
@@ -287,7 +287,7 @@ AJAX.registerOnload('tbl_structure.js', function () {
         $(this).PMA_confirm(question, $(this).attr('href'), function (url) {
             PMA_ajaxShowMessage();
             AJAX.source = $this;
-            $.get(url, {'ajax_request' : true, 'ajax_page_request' : true}, AJAX.responseHandler);
+            $.post(url, {'ajax_request' : true, 'ajax_page_request' : true}, AJAX.responseHandler);
         }); // end $.PMA_confirm()
     }); //end Add key
 
@@ -462,6 +462,21 @@ AJAX.registerOnload('tbl_structure.js', function () {
             submitPartitionAction($link.attr('href'));
         }
     });
+
+    /**
+     * Handles remove partitioning
+     */
+    $(document).on('click', '#remove_partitioning.ajax', function (e) {
+        e.preventDefault();
+        var $link = $(this);
+        var question = PMA_messages.strRemovePartitioningWarning;
+        $link.PMA_confirm(question, $link.attr('href'), function (url) {
+            var submitData = '&ajax_request=true&ajax_page_request=true';
+            PMA_ajaxShowMessage();
+            AJAX.source = $link;
+            $.post(url, submitData, AJAX.responseHandler);
+        });
+    });
 });
 
 /** Handler for "More" dropdown in structure table rows */
