@@ -779,12 +779,11 @@ class LanguageManager
      */
     public function selectLanguage()
     {
-        $langs = $this->availableLanguages();
-
         // check forced language
         if (! empty($GLOBALS['cfg']['Lang'])) {
-            if (isset($langs[$GLOBALS['cfg']['Lang']])) {
-                return $langs[$GLOBALS['cfg']['Lang']];
+            $lang = $this->getLanguage($GLOBALS['cfg']['Lang']);
+            if ($lang !== false) {
+                return $lang;
             }
             $this->_lang_failed_cfg = true;
         }
@@ -792,28 +791,33 @@ class LanguageManager
         // Don't use REQUEST in following code as it might be confused by cookies
         // with same name. Check user requested language (POST)
         if (! empty($_POST['lang'])) {
-            if (isset($langs[$_POST['lang']])) {
-                return $langs[$_POST['lang']];
+            $lang = $this->getLanguage($_POST['lang']);
+            if ($lang !== false) {
+                return $lang;
             }
             $this->_lang_failed_request = true;
         }
 
         // check user requested language (GET)
         if (! empty($_GET['lang'])) {
-            if (isset($langs[$_GET['lang']])) {
-                return $langs[$_GET['lang']];
+            $lang = $this->getLanguage($_GET['lang']);
+            if ($lang !== false) {
+                return $lang;
             }
             $this->_lang_failed_request = true;
         }
 
         // check previous set language
         if (! empty($_COOKIE['pma_lang'])) {
-            if (isset($langs[$_COOKIE['pma_lang']])) {
-                return $langs[$_COOKIE['pma_lang']];
+            $lang = $this->getLanguage($_COOKIE['pma_lang']);
+            if ($lang !== false) {
+                return $lang;
             }
             $this->_lang_failed_cookie = true;
         }
 
+        $langs = $this->availableLanguages();
+
         // try to find out user's language by checking its HTTP_ACCEPT_LANGUAGE variable;
         // prevent XSS
         $accepted_languages = PMA_getenv('HTTP_ACCEPT_LANGUAGE');
