@@ -664,6 +664,30 @@ class ConfigTest extends PMATestCase
     public function cookieUris()
     {
         return array(
+            array(
+                '',
+                '/',
+            ),
+            array(
+                '/',
+                '/',
+            ),
+            array(
+                '/index.php',
+                '/',
+            ),
+            array(
+                '\\index.php',
+                '/',
+            ),
+            array(
+                '\\',
+                '/',
+            ),
+            array(
+                '\\path\\to\\index.php',
+                '/path/to/',
+            ),
             array(
                 '/foo/bar/phpmyadmin/index.php',
                 '/foo/bar/phpmyadmin/',
