@@ -255,17 +255,17 @@ class PMA_HeaderLocation_Test extends PHPUnit_Framework_TestCase
         $testUri_html = htmlspecialchars($testUri);
         $testUri_js = PMA_escapeJsString($testUri);
 
-        $header = "<html><head><title>- - -</title>
+        $header = "<html>\n<head>\n    <title>- - -</title>
     <meta http-equiv=\"expires\" content=\"0\">"
-            . "<meta http-equiv=\"Pragma\" content=\"no-cache\">"
-            . "<meta http-equiv=\"Cache-Control\" content=\"no-cache\">"
-            . "<meta http-equiv=\"Refresh\" content=\"0;url=" . $testUri_html . "\">"
-            . "<script type=\"text/javascript\">//<![CDATA[
+            . "\n    <meta http-equiv=\"Pragma\" content=\"no-cache\">"
+            . "\n    <meta http-equiv=\"Cache-Control\" content=\"no-cache\">"
+            . "\n    <meta http-equiv=\"Refresh\" content=\"0;url=" . $testUri_html . "\">"
+            . "\n    <script type=\"text/javascript\">\n        //<![CDATA[
         setTimeout(\"window.location = decodeURI('" . $testUri_js . "')\", 2000);
-        //]]></script></head>
-<body><script type=\"text/javascript\">//<![CDATA[
+        //]]>\n    </script>\n</head>
+<body>\n<script type=\"text/javascript\">\n    //<![CDATA[
     document.write('<p><a href=\"" . $testUri_html . "\">" . __('Go') . "</a></p>');
-    //]]></script></body></html>
+    //]]>\n</script>\n</body>\n</html>
 ";
 
         $this->expectOutputString($header);
