@@ -7,13 +7,14 @@
  */
 
 // Sets up the session
+use PMA\libraries\VersionInformation;
+
 define('PMA_MINIMUM_COMMON', true);
 require_once 'libraries/common.inc.php';
-require_once 'libraries/Util.class.php';
 require_once 'libraries/VersionInformation.php';
 
 // Always send the correct headers
-header('Content-type: application/json; charset=UTF-8');
+PMA_headerJSON();
 
 $versionInformation = new VersionInformation();
 $versionDetails = $versionInformation->getLatestVersion();
